/*
 * GnuAPDF Library
 *   Jon Sevy, jsevy@cs.drexel.edu
 * 
 * Based on GnuJPDF Library, authored by (among others)
 *   Peter T Mount, http://www.retep.org.uk/pdf/
 *   Eric Z. Beard, ericzbeard@hotmail.com
 *   Gilbert DeLeeuw, gil1@users.sourceforge.net
 *   Matthew Hreljac, mhreljac@hotmail.com  
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

package gnu.apdf;


import java.io.IOException;
import java.io.OutputStream;


/**
 * Base class for PDF pattern types.
 * 
 * @author jsevy
 *
 */
public abstract class PDFPattern extends PDFStream
{
    
    /**
     * 1 for a tiling pattern, 2 for a shading pattern
     */
    protected int patternType;
    
    
    
    public PDFPattern(int patternType)
    {
        super("/Pattern");
        this.patternType = patternType;
    }
    
    
    
    /**
     * Method to write the stream's information to the supplied output stream; called by the library when the PDF
     * docuemtn contents are being generated.
     */
    public void write(OutputStream os) throws IOException
    {
        writeStart(os);
        
        // write out the pattern type
        os.write("/PatternType ".getBytes());
        os.write(Integer.toString(patternType).getBytes());
        os.write("\n".getBytes());
        
        // write out our remaining dictionary stuff
        writeDictionary(os);
        
        // write the contents of the Stream's byte buffer, along with the usual
        // header and footer
        writeStream(os);
        
        // Unlike most PDF objects, we dont call writeEnd(os) because we
        // extend a stream
    }
    
    
    
    /**
     * This method must be defined by each subclass to write the dictionary data specific to the Pattern subclass. Note
     * that the standard fields /Type and /PatternType are written to the stream by the base class; only the subsequent
     * fields are needed. /Type /Pattern /PatternType <patternType
     * 
     * @param os
     * @throws IOException
     */
    public abstract void writeDictionary(OutputStream os) throws IOException;
    
}